@@ -3,6 +3,7 @@ import os
 import platform
 import ssl
 import time
+import socket
 import shutil
 import urllib
 import logging
@@ -22,7 +23,7 @@ import html2text
 import youtube_dl
 
 from youtube_dl.utils import format_bytes, timeconvert
-from requests.exceptions import InvalidSchema, InvalidURL, MissingSchema
+from requests.exceptions import InvalidSchema, InvalidURL, MissingSchema, RequestException
 
 from moodle_dl.state_recorder.file import File
 from moodle_dl.state_recorder.course import Course
@@ -381,12 +382,15 @@ class URLTarget(object):
                 headers=RequestHelper.stdHeader,
                 verify=self.verify_cert,
                 allow_redirects=True,
+                timeout=60,
             )
         except (InvalidSchema, InvalidURL, MissingSchema):
             # don't download urls like 'mailto:name@provider.com'
             logging.debug('T%s - Attempt is aborted because the URL has no correct format', self.thread_id)
             self.success = True
             return False
+        except RequestException as error:
+            raise ConnectionError("Connection error: %s" % str(error)) from None
 
         if not response.ok:
             # The URL reports an HTTP error, so we give up trying to download the URL.
@@ -467,7 +471,7 @@ class URLTarget(object):
 
             # if we want we could save ydl.cookiejar (Also the cookiejar of moodle-dl)
 
-            if self.youtube_dl_failed_with_error is True:
+            if self.youtube_dl_failed_with_error is True and not self.options.get('ignore_ytdl_errors', False):
                 if not delete_if_successful:
                     # cleanup the url-link file
                     try:
@@ -481,7 +485,8 @@ class URLTarget(object):
                         )
                 self.success = False
                 raise RuntimeError(
-                    'Youtube-dl could not download the URL. For details see youtube-dl error messages in the log file'
+                    'Youtube-dl could not download the URL. For details see youtube-dl error messages in the log file. '
+                    + 'You can ignore this error by running `moodle-dl --ignore-ytdl-errors` once.'
                 )
 
         logging.debug('T%s - Downloading file directly', self.thread_id)
@@ -749,7 +754,7 @@ class URLTarget(object):
             self.success = True
 
         except Exception as e:
-            self.error = traceback.format_exc() + '\nError:' + str(e)
+            self.error = str(e)
             filesize = 0
             try:
                 filesize = os.path.getsize(self.file.saved_to)
@@ -757,6 +762,7 @@ class URLTarget(object):
                 pass
 
             logging.error('T%s - Error while trying to download file: %s', self.thread_id, self)
+            logging.error('T%s - Traceback:\n%s', self.thread_id, traceback.format_exc())
 
             if self.downloaded == 0 and filesize == 0:
                 try:
@@ -796,7 +802,7 @@ class URLTarget(object):
                 cookie_jar.load(ignore_discard=True, ignore_expires=True)
                 cookie_jar.add_cookie_header(request)
 
-        with contextlib.closing(urllib.request.urlopen(request, context=context)) as fp:
+        with contextlib.closing(urllib.request.urlopen(request, context=context, timeout=60)) as fp:
             headers = fp.info()
 
             # Just return the local path and the 'headers' for file://
@@ -826,7 +832,11 @@ class URLTarget(object):
                     reporthook(blocknum, bs, size)
 
                 while True:
-                    block = fp.read(bs)
+                    try:
+                        block = fp.read(bs)
+                    except (socket.timeout, socket.error) as error:
+                        raise ConnectionError("Connection error: %s" % str(error)) from None
+
                     if not block:
                         break
                     read += len(block)
