@@ -7,6 +7,7 @@ import requests
 import logging
 
 from http.cookiejar import MozillaCookieJar
+from requests.exceptions import RequestException
 
 
 class RequestHelper:
@@ -72,7 +73,10 @@ class RequestHelper:
             if os.path.exists(cookie_jar_path):
                 session.cookies.load(ignore_discard=True, ignore_expires=True)
 
-        response = session.post(url, data=data_urlencoded, headers=self.stdHeader, verify=self.verify)
+        try:
+            response = session.post(url, data=data_urlencoded, headers=self.stdHeader, verify=self.verify, timeout=60)
+        except RequestException as error:
+            raise ConnectionError("Connection error: %s" % str(error)) from None
 
         if cookie_jar_path is not None:
             for cookie in session.cookies:
@@ -98,8 +102,10 @@ class RequestHelper:
 
             if os.path.exists(cookie_jar_path):
                 session.cookies.load(ignore_discard=True, ignore_expires=True)
-
-        response = session.get(url, headers=self.stdHeader, verify=self.verify)
+        try:
+            response = session.get(url, headers=self.stdHeader, verify=self.verify, timeout=60)
+        except RequestException as error:
+            raise ConnectionError("Connection error: %s" % str(error)) from None
 
         if cookie_jar_path is not None:
             session.cookies.save(ignore_discard=True, ignore_expires=True)
@@ -121,7 +127,10 @@ class RequestHelper:
         data_urlencoded = self._get_POST_DATA(function, self.token, data)
         url = self._get_REST_POST_URL(self.url_base, function)
 
-        response = requests.post(url, data=data_urlencoded, headers=self.stdHeader, verify=self.verify)
+        try:
+            response = requests.post(url, data=data_urlencoded, headers=self.stdHeader, verify=self.verify, timeout=60)
+        except RequestException as error:
+            raise ConnectionError("Connection error: %s" % str(error)) from None
 
         json_result = self._initial_parse(response)
         if self.log_responses and function not in ['tool_mobile_get_autologin_key']:
@@ -170,13 +179,16 @@ class RequestHelper:
         @return: The JSON response returned by the Moodle System, already
         checked for errors.
         """
-
-        response = requests.post(
-            '%slogin/token.php' % (self.url_base),
-            data=urllib.parse.urlencode(data),
-            headers=self.stdHeader,
-            verify=self.verify,
-        )
+        try:
+            response = requests.post(
+                '%slogin/token.php' % (self.url_base),
+                data=urllib.parse.urlencode(data),
+                headers=self.stdHeader,
+                verify=self.verify,
+                timeout=60,
+            )
+        except RequestException as error:
+            raise ConnectionError("Connection error: %s" % str(error)) from None
 
         return self._initial_parse(response)
 
@@ -184,7 +196,7 @@ class RequestHelper:
     def _check_response_code(response):
         # Normally Moodle answer with response 200
         if response.status_code != 200:
-            raise RuntimeError(
+            raise RequestRejectedError(
                 'An Unexpected Error happened on side of the Moodle System!'
                 + (' Status-Code: %s' % str(response.status_code))
                 + ('\nHeader: %s' % response.headers)
@@ -200,7 +212,10 @@ class RequestHelper:
         """
 
         url = '%slib/upgrade.txt' % (self.url_base)
-        response = requests.get(url, headers=self.stdHeader, verify=self.verify)
+        try:
+            response = requests.get(url, headers=self.stdHeader, verify=self.verify, timeout=60)
+        except RequestException as error:
+            raise ConnectionError("Connection error: %s" % str(error)) from None
 
         self._check_response_code(response)
 
@@ -231,12 +246,14 @@ class RequestHelper:
         # Try to parse the JSON
         try:
             response_extracted = response.json()
+        except ValueError as error:
+            raise RequestRejectedError('The Moodle Mobile API does not appear to be available at this time.') from error
         except Exception as error:
-            raise RuntimeError(
+            raise RequestRejectedError(
                 'An Unexpected Error occurred while trying'
                 + ' to parse the json response! Moodle'
-                + ' response: %s.\nError: %s' % (response.read(), error)
-            )
+                + ' response: %s.\nError: %s' % (response.text, error)
+            ) from error
         # Check for known errors
         if 'error' in response_extracted:
             error = response_extracted.get('error', '')
@@ -256,6 +273,11 @@ class RequestHelper:
             errorcode = response_extracted.get('errorcode', '')
             message = response_extracted.get('message', '')
 
+            if errorcode == 'invalidtoken':
+                raise RequestRejectedError(
+                    'Your Moodle token has expired. To create a new one run "moodle-dl -nt -u USERNAME -pw PASSWORD"'
+                )
+
             raise RequestRejectedError(
                 'The Moodle System rejected the Request.'
                 + ' Details: %s (Errorcode: %s, Message: %s)' % (exception, errorcode, message)
